import { useEffect } from 'react';
import { dispatch, useCurrentRound } from '../../../domain/gameStore';
import { FROZEN, RACE } from '../../../domain/ruleSets';
import { useGameConfig } from '../../../hooks/useGameInfo';
import usePreventNavigation from '../../../hooks/usePreventNavigation';
import Loading from '../../util/Loading';
import styles from './GamePanel.module.css';
import GuessPane from './GuessPane';
import PositionedStreetView from './PositionedStreetView';
import RaceMode from './RaceMode';

const GamePanel = () => {
  // warn the user if they navigate away
  usePreventNavigation();
  const { ruleSet } = useGameConfig();
  const finished = useCurrentRound() === null;
  useEffect(
    () => {
      if (finished) {
        dispatch.goToSummary();
      }
    },
    [ finished ]
  );

  return finished ? (
    <Loading />
  ) : (
    <div className={styles.page}>
      {ruleSet === RACE && <RaceMode rate={1000} cutoffTime={10}/>}
      <div className={styles.streetview}>
        <PositionedStreetView />
        {ruleSet === FROZEN && <div className={styles.freeze} />}
      </div>
      <GuessPane />
    </div>
  );
};

export default GamePanel;